==> confine-controller-0.9.7.tar.gz: confine-controller-0.9.7/controller/apps/pings/migrations/0005_auto__chg_field_ping_date.py <==
# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'Ping.date'
        db.alter_column(u'pings_ping', 'date', self.gf('django.db.models.fields.DateTimeField')(default=datetime.datetime(2013, 10, 23, 0, 0)))

    def backwards(self, orm):

        # Changing field 'Ping.date'
        db.alter_column(u'pings_ping', 'date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, null=True))

    models = {
        u'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'pings.ping': {
            'Meta': {'ordering': "('-date',)", 'object_name': 'Ping', 'index_together': "[['object_id', 'content_type', 'date']]"},
            'avg': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['contenttypes.ContentType']"}),
            'date': ('django.db.models.fields.DateTimeField', [], {}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'max': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'mdev': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'min': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'packet_loss': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True'}),
            'samples': ('django.db.models.fields.PositiveIntegerField', [], {'default': '4'})
        }
    }

    complete_apps = ['pings']

==> confine-controller-0.11.2.tar.gz: confine-controller-0.11.2/controller/apps/pings/migrations/0005_auto__chg_field_ping_date.py <==
# -*- coding: utf-8 -*-
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models
from django.utils import timezone


class Migration(SchemaMigration):

    def forwards(self, orm):

        # Changing field 'Ping.date'
        db.alter_column(u'pings_ping', 'date', self.gf('django.db.models.fields.DateTimeField')(
            default=datetime.datetime(2013, 10, 23, 0, 0, tzinfo=timezone.get_default_timezone())))

    def backwards(self, orm):

        # Changing field 'Ping.date'
        db.alter_column(u'pings_ping', 'date', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, null=True))

    models = {
        u'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        u'pings.ping': {
            'Meta': {'ordering': "('-date',)", 'object_name': 'Ping', 'index_together': "[['object_id', 'content_type', 'date']]"},
            'avg': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': u"orm['contenttypes.ContentType']"}),
            'date': ('django.db.models.fields.DateTimeField', [], {}),
            u'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'max': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'mdev': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'min': ('django.db.models.fields.DecimalField', [], {'null': 'True', 'max_digits': '9', 'decimal_places': '3'}),
            'object_id': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'packet_loss': ('django.db.models.fields.PositiveIntegerField', [], {'null': 'True'}),
            'samples': ('django.db.models.fields.PositiveIntegerField', [], {'default': '4'})
        }
    }

    complete_apps = ['pings']
